<?php

declare(strict_types=1);

namespace Bolt\Utils;

/**
 * This class is used to convert PHP date format to moment.js format.
 *
 * @author Yonel Ceruto <yonelceruto@gmail.com>
 */
class MomentFormatConverter
{
    /**
     * This defines the mapping between PHP ICU date format (key) and moment.js date format (value)
     * For ICU formats see http://userguide.icu-project.org/formatparse/datetime#TOC-Date-Time-Format-Syntax
     * For Moment formats see http://momentjs.com/docs/#/displaying/format/.
     *
     * @var array
     */
    private static $formatConvertRules = [
        // year
        'yyyy' => 'YYYY',
        'yy' => 'YY',
        'y' => 'YYYY',
        // day
        'dd' => 'DD',
        'd' => 'D',
        // day of week
        'EE' => 'ddd',
        'EEEEEE' => 'dd',
        // timezone
        'ZZZZZ' => 'Z',
        'ZZZ' => 'ZZ',
        // letter 'T'
        '\'T\'' => 'T',
    ];

    /**
     * Returns associated moment.js format.
     */
    public static function convert(string $format): string
    {
        return strtr($format, static::$formatConvertRules);
    }
}
